@@ -3,7 +3,7 @@ fusion.dinla <- function(data, n.latent = 1, bans = 0, pp.offset, verbose = FALS
 
 
   if (!requireNamespace("INLA", quietly = TRUE)) {
-    stop("Package 'INLA' needed for this function to work. Please install it first, visit http://www.r-inla.org/download",
+    stop("Package 'INLA' needed for this function to work. Please install it first, visit https://www.r-inla.org/download-install",
          call. = FALSE)
   }
 
